@@ -1,7 +1,7 @@
+from __future__ import annotations
+
 import ast
 from typing import Iterable
-from typing import List
-from typing import Tuple
 
 from tokenize_rt import Offset
 from tokenize_rt import Token
@@ -15,7 +15,7 @@ from pyupgrade._token_helpers import find_token
 
 def _replace_celementtree_with_elementtree(
         i: int,
-        tokens: List[Token],
+        tokens: list[Token],
 ) -> None:
     j = find_token(tokens, i, 'cElementTree')
     tokens[j] = tokens[j]._replace(src='ElementTree')
@@ -26,7 +26,7 @@ def visit_ImportFrom(
         state: State,
         node: ast.ImportFrom,
         parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
             state.settings.min_version >= (3,) and
             node.module == 'xml.etree.cElementTree' and
@@ -40,7 +40,7 @@ def visit_Import(
         state: State,
         node: ast.Import,
         parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         state.settings.min_version >= (3,) and
         len(node.names) == 1 and
